@@ -15,20 +15,25 @@
 
 #include <QObject>
 #include <QWidget>
+#include <QPersistentModelIndex>
+#include <lxqtglobals.h>
 
-namespace LxQt {
+namespace LXQt {
   class Settings;
 }
 
+namespace Ui {
+class SelectWnd;
+}
+
 class XCursorThemeModel;
 
-#include "ui_selectwnd.h"
-class SelectWnd : public QWidget, private Ui_SelectWnd
+class LXQT_API SelectWnd : public QWidget
 {
     Q_OBJECT
 
 public:
-    SelectWnd (LxQt::Settings* settings, QWidget *parent=0);
+    SelectWnd (LXQt::Settings* settings, QWidget *parent=0);
     ~SelectWnd ();
 
 public slots:
@@ -53,7 +58,8 @@ private slots:
 private:
     XCursorThemeModel *mModel;
     QPersistentModelIndex mAppliedIndex;
-    LxQt::Settings* mSettings;
+    LXQt::Settings* mSettings;
+    Ui::SelectWnd *ui;
 };
 
 #endif
