@@ -33,6 +33,8 @@
 #include <QtDebug>
 #include <QMessageBox>
 #include <QStyledItemDelegate>
+#include <QShortcut>
+#include <QKeySequence>
 
 #include <XdgDesktopFile>
 #include <XdgIcon>
@@ -43,7 +45,7 @@
 #include "qcategorydrawer.h"
 #include "qcategorizedsortfilterproxymodel.h"
 
-namespace LxQtConfig {
+namespace LXQtConfig {
 
 struct ConfigPaneData: public QSharedData
 {
@@ -91,11 +93,11 @@ public:
         DomElementIterator it(xdgMenu.xml().documentElement() , "Menu");
         while(it.hasNext())
         {
-            this->builGroup(it.next());
+            this->buildGroup(it.next());
         }
     }
 
-    void builGroup(const QDomElement& xml)
+    void buildGroup(const QDomElement& xml)
     {
         QString category;
         if (! xml.attribute("title").isEmpty())
@@ -170,19 +172,34 @@ public:
 
     QSize sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const
     {
-        int height = QStyledItemDelegate::sizeHint(option, index).height();
-        return QSize(mView->gridSize().width(), qMin(height, mView->gridSize().height()));
+        /* We let Qt calculate the real cell size but consider the 4-px margin
+           around each cell and try to add a 2-px margin around the selection
+           rectangle for styles that, unlike Fusion, highlight the whole item. */
+        QStyleOptionViewItem opt = option;
+        int delta = opt.rect.width() - (mView->gridSize().width() - 8);
+        if (delta > 0)
+          opt.rect.adjust(delta/2, 0 , -delta/2, 0);
+        QSize defaultSize = QStyledItemDelegate::sizeHint(opt, index);
+        return QSize(qMin(defaultSize.width() + 4, mView->gridSize().width() - 8),
+                     qMin(defaultSize.height() + 4, mView->gridSize().height() - 8));
     }
 
 protected:
     void paint(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index) const
     {
-        QStyleOptionViewItemV4 opt = option;
+        QStyleOptionViewItem opt = option;
         initStyleOption(&opt, index);
 
-        QSize size(mView->gridSize().width(), mView->iconSize().height());
-        QPixmap pixmap = opt.icon.pixmap(mView->iconSize());
-        opt.icon = QIcon(pixmap.copy(QRect(QPoint(0, 0), size)));
+        const QSize & iconSize = option.decorationSize;
+        QSize size(mView->gridSize().width() - 8, // 4-px margin around each cell
+                   iconSize.height());
+        // for having sharp non-scalable icons with HDPI
+        int dpr = qApp->devicePixelRatio();
+        if (dpr < 1) dpr = 1;
+        QPixmap pixmap = opt.icon.pixmap(iconSize / dpr); // -> Qt doc -> QIcon::pixmap()
+        if (dpr > 1 && pixmap.size() == iconSize) // exceptional (scalable or not from icon set)
+            pixmap = opt.icon.pixmap(iconSize);
+        opt.icon = QIcon(pixmap.copy(QRect(QPoint(0, 0), size * dpr)));
         opt.decorationSize = size;
 
         QApplication::style()->drawControl(QStyle::CE_ItemViewItem, &opt, painter);
@@ -193,57 +210,31 @@ private:
 };
 
 
-LxQtConfig::MainWindow::MainWindow() : QMainWindow()
+LXQtConfig::MainWindow::MainWindow() : QMainWindow()
 {
     setupUi(this);
+    view->installEventFilter(this);
+
+    /* To always have the intended layout on startup,
+       the listview should be shown after it's fully formed. */
+    view->hide();
 
     model = new ConfigPaneModel();
 
     view->setViewMode(QListView::IconMode);
-    view->setIconSize(QSize(32, 32));
-    view->setGridSize(QSize(100, 100));
     view->setWordWrap(true);
     view->setUniformItemSizes(true);
     view->setCategoryDrawer(new QCategoryDrawerV3(view));
 
-    // Qt bug: signal activated should respect the hint, but it doesn't
-    if (style()->styleHint(QStyle::SH_ItemView_ActivateItemOnSingleClick))
-        connect(view, SIGNAL(clicked(const QModelIndex&)), SLOT(activateItem(const QModelIndex&)));
-    else
-        connect(view, SIGNAL(doubleClicked(const QModelIndex&)), SLOT(activateItem(const QModelIndex&)));
+    connect(view, &QAbstractItemView::activated, [this] (const QModelIndex & index) { pendingActivation = index; });
     view->setFocus();
 
+    QTimer::singleShot(0, [this] { setSizing(); });
     QTimer::singleShot(1, this, SLOT(load()));
+    new QShortcut{QKeySequence{Qt::CTRL + Qt::Key_Q}, this, SLOT(close())};
 }
 
-bool LxQtConfig::MainWindow::event(QEvent* event)
-{
-    // LXQt's Qt5 plugin sends a ThemeChange event
-    if (event->type() == QEvent::ThemeChange)
-    {
-        // Qt bug: signal activated should respect the hint, but it doesn't
-        if (style()->styleHint(QStyle::SH_ItemView_ActivateItemOnSingleClick))
-        {
-            view->disconnect(this);
-            connect(view, SIGNAL(clicked(const QModelIndex&)), SLOT(activateItem(const QModelIndex&)));
-        }
-        else
-        {
-            view->disconnect(this);
-            connect(view, SIGNAL(doubleClicked(const QModelIndex&)), SLOT(activateItem(const QModelIndex&)));
-        }
-    }
-    else if (event->type() == QEvent::KeyRelease)
-    {
-        int key = static_cast<QKeyEvent*>(event)->key();
-        if (key == Qt::Key_Enter || key == Qt::Key_Return)
-            activateItem(view->selectionModel()->currentIndex());
-    }
-
-    return QMainWindow::event(event);
-}
-
-void LxQtConfig::MainWindow::load()
+void LXQtConfig::MainWindow::load()
 {
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
@@ -254,14 +245,85 @@ void LxQtConfig::MainWindow::load()
     view->setModel(proxyModel);
     view->setItemDelegate(new ConfigItemDelegate(view));
 
+    view->show();
+
     QApplication::restoreOverrideCursor();
 }
 
-void LxQtConfig::MainWindow::activateItem(const QModelIndex &index)
+void LXQtConfig::MainWindow::activateItem()
 {
-    if (!index.isValid())
-        return;
+    if (pendingActivation.isValid())
+    {
+        model->activateItem(pendingActivation);
+        pendingActivation = QModelIndex{};
+    }
+}
 
-    QModelIndex orig = proxyModel->mapToSource(index);
-    model->activateItem(orig);
+/*Note: all this delayed activation is here to workaround the auto-repeated
+ * Enter/Return key activation -> if the user keeps pressing the enter/return
+ * we normaly will keep activating (spawning new processes) until the focus
+ * isn't stolen from our window. New process is not spawned until the
+ * (non-autorepeated) KeyRelease is delivered.
+ *
+ * ref https://github.com/lxde/lxqt/issues/965
+ */
+bool LXQtConfig::MainWindow::eventFilter(QObject * watched, QEvent * event)
+{
+    if (view != watched)
+        return false;
+    switch (event->type())
+    {
+        case QEvent::KeyPress:
+        case QEvent::KeyRelease:
+            {
+                QKeyEvent * ev = dynamic_cast<QKeyEvent *>(event);
+                switch (ev->key())
+                {
+                    case Qt::Key_Enter:
+                    case Qt::Key_Return:
+                        if (QEvent::KeyRelease == ev->type() && !ev->isAutoRepeat())
+                            activateItem();
+                }
+            }
+            break;
+        case QEvent::MouseButtonRelease:
+            activateItem();
+            break;
+        default:
+            //keep warnings quiet
+            break;
+    }
+    return false;
+}
+
+void LXQtConfig::MainWindow::setSizing()
+{
+    // consult the style to know the icon size
+    int iconSize = qBound(16, view->decorationSize().height(), 256);
+    // DPR is automatically taken into account in setIconSize()
+    // but wee need to consider it explicitly below
+    int dpr = qApp->devicePixelRatio();
+    if (dpr < 1) dpr = 1;
+    iconSize *= dpr;
+    /* To have an appropriate grid size, we suppose that
+     *
+     * (1) The text has 3 lines and each line has 16 chars (for languages like German), at most;
+     * (2) The selection rect has a margin of 2 px, at most;
+     * (3) There is, at most, a 3-px spacing between text and icon; and
+     * (4) There is a 4-px margin around each cell.
+     */
+    QFontMetrics fm = fontMetrics();
+    int textWidth = fm.averageCharWidth() * 16;
+    int textHeight = fm.lineSpacing() * 3;
+    QSize grid;
+    grid.setWidth(qMax(iconSize, textWidth) + 4);
+    grid.setHeight(iconSize + textHeight + 4 + 3);
+    view->setGridSize(grid + QSize(8, 8));
+}
+
+bool LXQtConfig::MainWindow::event(QEvent * event)
+{
+    if (QEvent::StyleChange == event->type())
+        setSizing();
+    return QMainWindow::event(event);
 }
